@@ -1,11 +1,11 @@
 var classjuce_1_1SmoothedValue =
 [
-    [ "MultiplicativeVoid", "classjuce_1_1SmoothedValue.html#a85d03ffefc611aefcc3460287ab12155", null ],
     [ "SmoothedValue", "classjuce_1_1SmoothedValue.html#ac41bcc65289b0c3f5f94df8ebe9eefc7", null ],
     [ "SmoothedValue", "classjuce_1_1SmoothedValue.html#a94e2da26e156c02f5ea738f62ed0eec5", null ],
     [ "getNextValue", "classjuce_1_1SmoothedValue.html#a22f1c8709c656240ba3a9a07d2659677", null ],
     [ "reset", "classjuce_1_1SmoothedValue.html#a9e89cc427e19a52d931cd7a399e1fb77", null ],
     [ "reset", "classjuce_1_1SmoothedValue.html#ae3ae444d67c5e618fba952dc0be887ef", null ],
     [ "setTargetValue", "classjuce_1_1SmoothedValue.html#affa9cda793d065c3b86f7246b24ccbe1", null ],
+    [ "setValue", "classjuce_1_1SmoothedValue.html#a37c8f24b556604b54e17bd4b34d043cc", null ],
     [ "skip", "classjuce_1_1SmoothedValue.html#a090d2b4d764fa3f4df2e50a6c73dfd05", null ]
 ];
\ No newline at end of file
