@@ -1,12 +1,6 @@
 var classjuce_1_1UnitTestRunner =
 [
-    [ "TestResult", "classjuce_1_1UnitTestRunner.html#structjuce_1_1UnitTestRunner_1_1TestResult", [
-      [ "failures", "classjuce_1_1UnitTestRunner.html#a25af182e95e43f78303f96d1b47ec209", null ],
-      [ "messages", "classjuce_1_1UnitTestRunner.html#a887f85269b58fcbab200feec024689a4", null ],
-      [ "passes", "classjuce_1_1UnitTestRunner.html#ae9b9add42ad0909ae539b57857ea04f8", null ],
-      [ "subcategoryName", "classjuce_1_1UnitTestRunner.html#ac0f666c365de2737834565d2d4117a36", null ],
-      [ "unitTestName", "classjuce_1_1UnitTestRunner.html#ab677c0bbe159375d828d1e6ba3f81771", null ]
-    ] ],
+    [ "TestResult", "structjuce_1_1UnitTestRunner_1_1TestResult.html", "structjuce_1_1UnitTestRunner_1_1TestResult" ],
     [ "~UnitTestRunner", "classjuce_1_1UnitTestRunner.html#a1e6f06285fe053758cbbb136a4e7c718", null ],
     [ "getNumResults", "classjuce_1_1UnitTestRunner.html#a44b3390caaa8a6b5d52b11150802ba2e", null ],
     [ "getResult", "classjuce_1_1UnitTestRunner.html#a3d0bc5c8543023b1d83387f2bba0e2b5", null ],
