@@ -6,5 +6,6 @@ var searchData=
   ['keystate_3',['KeyState',['../structjuce_1_1MPENote.html#a3bc29d451148a39a66a03afb683a28ef',1,'juce::MPENote']]],
   ['keystate_4',['keyState',['../structjuce_1_1MPENote.html#ae4ad7f64b101086591572dce66d25110',1,'juce::MPENote']]],
   ['kill_5',['kill',['../classjuce_1_1ChildProcess.html#ae69095fa75d2f3e2727b3f4ea9213c47',1,'juce::ChildProcess']]],
-  ['killslaveprocess_6',['killSlaveProcess',['../classjuce_1_1ChildProcessMaster.html#a64dcd715d4cec742d147cb79a0493e9b',1,'juce::ChildProcessMaster']]]
+  ['killworkerprocess_6',['killWorkerProcess',['../classjuce_1_1ChildProcessCoordinator.html#a0a806d934f18106d08ce7d9a9e101653',1,'juce::ChildProcessCoordinator']]],
+  ['kind_7',['Kind',['../structjuce_1_1universal__midi__packets_1_1SysEx7.html#a32ff33027adc7e0c978f12d5947c540d',1,'juce::universal_midi_packets::SysEx7']]]
 ];
