@@ -1,5 +1,5 @@
 var searchData=
 [
   ['zipfile_0',['ZipFile',['../classjuce_1_1ZipFile.html#a72af2d90154cb153508df2ccafd46a44',1,'juce::ZipFile::ZipFile(const File &amp;file)'],['../classjuce_1_1ZipFile.html#a59985b0e040833121a116768aba5c41b',1,'juce::ZipFile::ZipFile(InputStream *inputStream, bool deleteStreamWhenDestroyed)'],['../classjuce_1_1ZipFile.html#aa295c8650643910a7a4b8dee100376a8',1,'juce::ZipFile::ZipFile(InputStream &amp;inputStream)'],['../classjuce_1_1ZipFile.html#a20b256262d9cafce7e6afdd341e1e528',1,'juce::ZipFile::ZipFile(InputSource *inputSource)']]],
-  ['zonelayoutchanged_1',['zoneLayoutChanged',['../classjuce_1_1MPEZoneLayout_1_1Listener.html#a34bdf3ce7b2f629da5a06c5d719026eb',1,'juce::MPEZoneLayout::Listener']]]
+  ['zonelayoutchanged_1',['zoneLayoutChanged',['../classjuce_1_1MPEInstrument_1_1Listener.html#a4cccd27d8e165ac9bc2b691967304297',1,'juce::MPEInstrument::Listener::zoneLayoutChanged()'],['../classjuce_1_1MPEZoneLayout_1_1Listener.html#a34bdf3ce7b2f629da5a06c5d719026eb',1,'juce::MPEZoneLayout::Listener::zoneLayoutChanged()']]]
 ];
