@@ -2,5 +2,5 @@ var searchData=
 [
   ['keysignaturemetaevent_0',['keySignatureMetaEvent',['../classjuce_1_1MidiMessage.html#a92c9702f55176ab6760594185572798c',1,'juce::MidiMessage']]],
   ['kill_1',['kill',['../classjuce_1_1ChildProcess.html#ae69095fa75d2f3e2727b3f4ea9213c47',1,'juce::ChildProcess']]],
-  ['killslaveprocess_2',['killSlaveProcess',['../classjuce_1_1ChildProcessMaster.html#a64dcd715d4cec742d147cb79a0493e9b',1,'juce::ChildProcessMaster']]]
+  ['killworkerprocess_2',['killWorkerProcess',['../classjuce_1_1ChildProcessCoordinator.html#a0a806d934f18106d08ce7d9a9e101653',1,'juce::ChildProcessCoordinator']]]
 ];
