@@ -1,7 +1,7 @@
 var searchData=
 [
   ['uncompressedsize_0',['uncompressedSize',['../classjuce_1_1ZipFile.html#a57bb2624bcd7f6f4023c144c877c9027',1,'juce::ZipFile::ZipEntry']]],
-  ['unittestname_1',['unitTestName',['../classjuce_1_1UnitTestRunner.html#ab677c0bbe159375d828d1e6ba3f81771',1,'juce::UnitTestRunner::TestResult']]],
+  ['unittestname_1',['unitTestName',['../structjuce_1_1UnitTestRunner_1_1TestResult.html#ab677c0bbe159375d828d1e6ba3f81771',1,'juce::UnitTestRunner::TestResult']]],
   ['usedefaultinputchannels_2',['useDefaultInputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#a21edcaa3d650dbb62205c375ef36f8cb',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
   ['usedefaultoutputchannels_3',['useDefaultOutputChannels',['../structjuce_1_1AudioDeviceManager_1_1AudioDeviceSetup.html#ae1cc4ca6e512d83527f0e80863438ec7',1,'juce::AudioDeviceManager::AudioDeviceSetup']]],
   ['usesfloatingpointdata_4',['usesFloatingPointData',['../classjuce_1_1AudioFormatReader.html#a07b44f6fb2aa02226943244ffc36b0ed',1,'juce::AudioFormatReader::usesFloatingPointData'],['../classjuce_1_1AudioFormatWriter.html#a141cb99ea9e4a9c576600eab06893c38',1,'juce::AudioFormatWriter::usesFloatingPointData']]]
